@@ -51,7 +51,7 @@ if sys.version_info[:2] >= (3, 8):  # pragma: no cover
     from com2ann import com2ann
 
 
-__version__ = "0.3.3"
+__version__ = "0.3.4"
 __all__ = ["shed", "docshed"]
 
 _version_map = {
@@ -144,7 +144,7 @@ def shed(
             remove_duplicate_keys=True,
             remove_unused_variables=True,
         )
-        source_code = isort.code(
+        source_code = isort.code(  # type: ignore
             source_code,
             known_first_party=first_party_imports,
             known_local_folder={"tests"},
